@@ -9,7 +9,7 @@
 """
 from __future__ import absolute_import
 
-from .state import SOFTWARE_INFO
+from .state import SOFTWARE_INFO, active_requests, total_count
 
 
 class Heart(object):
@@ -34,13 +34,17 @@ class Heart(object):
         self.eventer.on_disabled.add(self.stop)
 
     def _send(self, event):
-        return self.eventer.send(event, freq=self.interval, **SOFTWARE_INFO)
+        return self.eventer.send(event, freq=self.interval,
+                                 active=len(active_requests),
+                                 processed=sum(total_count.itervalues()),
+                                 **SOFTWARE_INFO)
 
     def start(self):
         if self.eventer.enabled:
             self._send('worker-online')
-            self.tref = self.timer.apply_interval(self.interval * 1000.0,
-                    self._send, ('worker-heartbeat', ))
+            self.tref = self.timer.apply_interval(
+                self.interval * 1000.0, self._send, ('worker-heartbeat', ),
+            )
 
     def stop(self):
         if self.tref is not None:
